from django.conf import settings


GALLERY_STYLES = getattr(
    settings, 'WIDGETBOX_GALLERY_STYLES',
    (('widgetbox/gallery.html', 'default'),)
)

FAQ_STYLES = getattr(
    settings, 'WIDGETBOX_FAQ_STYLES',
    (('widgetbox/faq-topic.html', 'default'),)
)

DIVIDER_SIZES = getattr(
    settings, 'WIDGETBOX_DIVIDER_SIZES', ())



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0011_auto_20150419_1006'),
        ('widgetbox', '0009_divider'),
    ]

    operations = [
        migrations.CreateModel(
            name='HTML',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('content', models.TextField(help_text=b'This is unsafe and potentially dangerous. Be aware of what you are doing.')),
            ],
            options={
                'db_table': 'widgetbox_html',
            },
            bases=('cms.cmsplugin',),
        ),
    ]



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .models import (
    Button, Quote,
    Gallery, GalleryImage,
    FaqTopic, Faq,
    Divider,
    HTML
)


class ButtonPlugin(CMSPluginBase):
    model = Button
    module = "Widget Box"
    name = "Button"
    render_template = "widgetbox/button.html"


class QuotePlugin(CMSPluginBase):
    model = Quote
    module = "Widget Box"
    name = "Quote"
    render_template = "widgetbox/quote.html"


class GalleryPlugin(CMSPluginBase):
    model = Gallery
    module = "Widget Box"
    name = "Gallery"
    allow_children = True
    child_classes = ["GalleryImagePlugin"]
    render_template = "widgetbox/gallery.html"


class GalleryImagePlugin(CMSPluginBase):
    model = GalleryImage
    module = "Widget Box"
    name = "Gallery Image"
    parent_classes = ["GalleryPlugin"]
    render_template = "widgetbox/gallery-image.html"


class FaqTopicPlugin(CMSPluginBase):
    model = FaqTopic
    module = "Widget Box"
    name = "FAQ Topic"
    allow_children = True
    child_classes = ["FaqPlugin"]

    def get_render_template(self, context, instance, placeholder):
        return instance.style


class FaqPlugin(CMSPluginBase):
    model = Faq
    module = "Widget Box"
    name = "FAQ"
    parent_classes = ["FaqTopicPlugin"]

    def get_render_template(self, context, instance, placeholder):
        return "widgetbox/faq.html"


class DividerPlugin(CMSPluginBase):
    model = Divider
    module = "Widget Box"
    name = "Vertical divider"
    render_template = "widgetbox/divider.html"


class HTMLPlugin(CMSPluginBase):
    model = HTML
    module = "Widget Box"
    name = "HTML (unsafe)"
    render_template = "widgetbox/html.html"


plugin_pool.register_plugin(ButtonPlugin)
plugin_pool.register_plugin(QuotePlugin)
plugin_pool.register_plugin(GalleryPlugin)
plugin_pool.register_plugin(GalleryImagePlugin)
plugin_pool.register_plugin(FaqTopicPlugin)
plugin_pool.register_plugin(FaqPlugin)
plugin_pool.register_plugin(DividerPlugin)
plugin_pool.register_plugin(HTMLPlugin)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('widgetbox', '0002_faq_faqtopic'),
    ]

    operations = [
        migrations.RenameField(
            model_name='faqtopic',
            old_name='title',
            new_name='topic',
        ),
        migrations.AlterField(
            model_name='faqtopic',
            name='style',
            field=models.CharField(default=b'widgetbox/faq-topic.html', max_length=100, choices=[(b'widgetbox/faq-topic.html', b'Default')]),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import cms.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0011_auto_20150419_1006'),
        ('widgetbox', '0007_auto_20150522_1634'),
    ]

    operations = [
        migrations.AddField(
            model_name='galleryimage',
            name='link_custom',
            field=models.CharField(max_length=400, blank=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='galleryimage',
            name='link_to_page',
            field=cms.models.fields.PageField(blank=True, to='cms.Page', null=True),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import djangocms_text_ckeditor.fields
import filer.fields.image
import cms.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0011_auto_20150419_1006'),
        ('filer', '__latest__'),
    ]

    operations = [
        migrations.CreateModel(
            name='ButtonPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(max_length=200)),
                ('subtitle', models.CharField(max_length=200, blank=True)),
                ('link_custom', models.CharField(max_length=400, blank=True)),
                ('icon', models.CharField(max_length=50, blank=True)),
                ('link_to_page', cms.models.fields.PageField(blank=True, to='cms.Page', null=True)),
            ],
            options={
                'db_table': 'widgetbox_buttons',
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='GalleryImagePlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(max_length=100, blank=True)),
                ('description', models.CharField(max_length=200, blank=True)),
                ('image', filer.fields.image.FilerImageField(to='filer.Image')),
            ],
            options={
                'db_table': 'widgetbox_gallery_images',
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='GalleryPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('style', models.CharField(default=b'default', max_length=100, choices=[(b'default', b'default')])),
            ],
            options={
                'db_table': 'widgetbox_galleries',
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='QuotePlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('content', djangocms_text_ckeditor.fields.HTMLField()),
                ('name', models.CharField(max_length=200)),
                ('link', models.CharField(max_length=400, blank=True)),
                ('image', filer.fields.image.FilerImageField(blank=True, to='filer.Image', null=True)),
            ],
            options={
                'db_table': 'widgetbox_quotes',
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('widgetbox', '0003_auto_20150522_0959'),
    ]

    operations = [
        migrations.RenameModel('ButtonPlugin', 'Button'),
        migrations.RenameModel('QuotePlugin', 'Quote'),
        migrations.RenameModel('GalleryPlugin', 'Gallery'),
        migrations.RenameModel('GalleryImagePlugin', 'GalleryImage'),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import djangocms_text_ckeditor.fields


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0011_auto_20150419_1006'),
        ('widgetbox', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Faq',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('question', models.CharField(max_length=400)),
                ('answer', djangocms_text_ckeditor.fields.HTMLField()),
            ],
            options={
                'db_table': 'widgetbox_faqs',
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='FaqTopic',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(max_length=400)),
                ('style', models.CharField(default=b'widgetbox/faqs/default.html', max_length=100, choices=[(b'widgetbox/faqs/default.html', b'Default')])),
            ],
            options={
                'db_table': 'widgetbox_faq_topics',
            },
            bases=('cms.cmsplugin',),
        ),
    ]



from django.utils.encoding import python_2_unicode_compatible

from django.db import models
from .settings import GALLERY_STYLES, FAQ_STYLES, DIVIDER_SIZES

from cms.models import CMSPlugin
from cms.models.fields import PageField

from djangocms_text_ckeditor.fields import HTMLField
from filer.fields.image import FilerImageField


class LinkMixin(object):
    def get_link(self):
        if self.link_custom:
            return self.link_custom
        elif self.link_to_page:
            return self.link_to_page.get_absolute_url()
        else:
            return ''


@python_2_unicode_compatible
class Button(LinkMixin, CMSPlugin):
    title = models.CharField(max_length=200)
    subtitle = models.CharField(max_length=200, blank=True)
    link_to_page = PageField(null=True, blank=True)
    link_custom = models.CharField(max_length=400, blank=True)
    icon = models.CharField(max_length=50, blank=True)

    class Meta:
        db_table = 'widgetbox_buttons'

    def __str__(self):
        return self.title


@python_2_unicode_compatible
class Quote(CMSPlugin):
    content = HTMLField()
    name = models.CharField(max_length=200)
    link = models.CharField(max_length=400, blank=True)
    image = FilerImageField(null=True, blank=True)

    class Meta:
        db_table = 'widgetbox_quotes'

    def __str__(self):
        return self.name


@python_2_unicode_compatible
class Gallery(CMSPlugin):
    style = models.CharField(
        max_length=100,
        choices=GALLERY_STYLES,
        default=GALLERY_STYLES[0][0]
    )

    class Meta:
        db_table = 'widgetbox_galleries'

    def __str__(self):
        return u'Gallery ({})'.format(self.style)

    def get_html_id(self):
        return u'gallery-{}'.format(self.pk)


@python_2_unicode_compatible
class GalleryImage(LinkMixin, CMSPlugin):
    image = FilerImageField()
    title = models.CharField(max_length=100, blank=True)
    description = models.CharField(max_length=200, blank=True)
    link_to_page = PageField(null=True, blank=True)
    link_custom = models.CharField(max_length=400, blank=True)

    class Meta:
        db_table = 'widgetbox_gallery_images'

    def __str__(self):
        return str(self.image)

    def get_title(self):
        return self.title or self.image.label

    def get_description(self):
        return self.description or self.image.description


@python_2_unicode_compatible
class FaqTopic(CMSPlugin):
    topic = models.CharField(max_length=400)
    style = models.CharField(
        max_length=100,
        choices=FAQ_STYLES, default=FAQ_STYLES[0][0]
    )

    class Meta:
        db_table = 'widgetbox_faq_topics'

    def __str__(self):
        return u'FAQ topic ({})'.format(self.style)


@python_2_unicode_compatible
class Faq(CMSPlugin):
    question = models.CharField(max_length=400)
    answer = HTMLField()

    class Meta:
        db_table = 'widgetbox_faqs'

    def __str__(self):
        return self.question


@python_2_unicode_compatible
class Divider(CMSPlugin):
    size = models.CharField(max_length=10, choices=DIVIDER_SIZES)

    class Meta:
        db_table = 'widgetbox_dividers'

    def __str__(self):
        return self.size


@python_2_unicode_compatible
class HTML(CMSPlugin):
    content = models.TextField(help_text="This is unsafe and potentially dangerous. "
                                         "Be aware of what you are doing.")

    class Meta:
        db_table = 'widgetbox_html'

    def __str__(self):
        return self.content[:80]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


def fix_cms_plugins(apps, schema_editor):
    CMSPlugin = apps.get_model('cms', 'CMSPlugin')
    CMSPlugin.objects.filter(plugin_type="CMSButtonPlugin").update(plugin_type="ButtonPlugin")
    CMSPlugin.objects.filter(plugin_type="CMSQuotePlugin").update(plugin_type="QuotePlugin")
    CMSPlugin.objects.filter(plugin_type="CMSGalleryPlugin").update(plugin_type="GalleryPlugin")
    CMSPlugin.objects.filter(plugin_type="CMSGalleryImagePlugin").update(plugin_type="GalleryImagePlugin")


class Migration(migrations.Migration):

    dependencies = [
        ('widgetbox', '0005_rename_model_button'),
    ]

    operations = [
        migrations.RunPython(fix_cms_plugins)
    ]
